function [T, Z] = nde_duffing(t, v0)
% 2D nonlinear differential equation for duffing equation
% INPUT 
%      t - time span for which the solution is computed, t=[T0 TFINAL]; 
%     v0 - initial conditions [z1(0), z2(0)];
% OUTPUT
%      Z - solution matrix. Each column correspond to each coordinate,
%          i.e., Y=[z1, z2].
%      T - time index
% GLOBAL VARIABLES


% run solver
options = odeset('RelTol',1e-4,'AbsTol',1e-4);
[T, Z] = ode45(@nonlindif, t, v0, options);

function dvec = nonlindif(t, vec)
% Here we simply write the system of first order differential 
% equations. Each equation in the system is treated as a 
% coordinate. In this case there are two equations, thus 
% two coordinates
% dz1/dt=...
% dz2/dt=...

% constants
global delta alpha beta B omega;

% coordinates
z1 = vec(1); % x
z2 = vec(2); % x'

% vector of coordinates second order dif. eq. 
dvec = zeros(2,1);

% dz1/dt=
dvec(1) = z2;
% dz2/dt=
dvec(2) = -delta.*z2 - alpha.*z1 - beta.*(z1.^3) + B*cos(omega*t);

return